@@ -5,6 +5,11 @@ from Quartz import *
 
 import os
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTLine (TestCase):
     def testTypes(self):
         self.assertIsInstance(CTLineRef, objc.objc_class)
@@ -19,12 +24,14 @@ class TestCTLine (TestCase):
         self.assertIsInstance(v, (int, long))
 
         self.assertResultIsCFRetained(CTLineCreateWithAttributedString)
-        token = CTLineCreateWithAttributedString(
-                CFAttributedStringCreate(None, u"-", None))
+        astr = CFAttributedStringCreate(None, b"-".decode('latin1'), None)
+        self.assertTrue(astr is not None)
+        token = CTLineCreateWithAttributedString(astr)
         self.assertIsInstance(token, CTLineRef)
 
-        line = CTLineCreateWithAttributedString(
-                CFAttributedStringCreate(None, u"hello world", None))
+        astr = CFAttributedStringCreate(None, b"hello world".decode('latin1'), None)
+        self.assertTrue(astr is not None)
+        line = CTLineCreateWithAttributedString(astr)
         self.assertIsInstance(line, CTLineRef)
 
         self.assertResultIsCFRetained(CTLineCreateTruncatedLine)
@@ -32,7 +39,7 @@ class TestCTLine (TestCase):
         self.assertIsInstance(v, CTLineRef)
 
         self.assertResultIsCFRetained(CTLineCreateJustifiedLine)
-        v = CTLineCreateJustifiedLine(line, 0.75, 20.0)
+        v = CTLineCreateJustifiedLine(line, 2.0, 123.0)
         self.assertIsInstance(v, CTLineRef)
 
         v = CTLineGetGlyphCount(line)
@@ -85,5 +92,24 @@ class TestCTLine (TestCase):
         if os.path.exists("/tmp/pyobjc.test.pdf"):
             os.unlink("/tmp/pyobjc.test.pdf")
 
+    @min_os_level("10.8")
+    def testConstants10_8(self):
+        self.assertEqual(kCTLineBoundsExcludeTypographicLeading, 1 << 0)
+        self.assertEqual(kCTLineBoundsExcludeTypographicShifts, 1 << 1)
+        self.assertEqual(kCTLineBoundsUseHangingPunctuation, 1 << 2)
+        self.assertEqual(kCTLineBoundsUseGlyphPathBounds, 1 << 3)
+        self.assertEqual(kCTLineBoundsUseOpticalBounds, 1 << 4)
+
+    @min_os_level("10.8")
+    def testFunctions10_8(self):
+        astr = CFAttributedStringCreate(None, b"-".decode('latin1'), None)
+        self.assertTrue(astr is not None)
+
+        token = CTLineCreateWithAttributedString(astr)
+        self.assertIsInstance(token, CTLineRef)
+
+        r = CTLineGetBoundsWithOptions(token, kCTLineBoundsExcludeTypographicLeading)
+        self.assertIsInstance(r, CGRect)
+
 if __name__ == "__main__":
     main()
