@@ -4,6 +4,11 @@ from CoreText import *
 from Foundation import NSDictionary
 from Quartz import *
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTRun (TestCase):
     def testTypes(self):
         self.assertIsCFType(CTRunRef)
@@ -15,11 +20,10 @@ class TestCTRun (TestCase):
         self.assertEqual(kCTRunStatusHasNonIdentityMatrix, (1 << 2))
 
     def testFunctions(self):
-        return
         self.assertIsInstance(CTRunGetTypeID(), (int, long))
 
         line = CTLineCreateWithAttributedString(
-                CFAttributedStringCreate(None, u"hello world", None))
+                CFAttributedStringCreate(None, b"hello world".decode('latin1'), None))
         self.assertIsInstance(line, CTLineRef)
 
         run = CTLineGetGlyphRuns(line)[0]
@@ -88,8 +92,29 @@ class TestCTRun (TestCase):
 
     @min_os_level('10.5')
     def testFunctions10_5(self):
-        self.fail('CTRunGetAdvancesPtr')
-        self.fail('CTRunGetAdvances')
+        self.assertArgIsOut(CTRunGetAdvances, 2)
+        self.assertArgSizeInArg(CTRunGetAdvances, 2, 1)
+
+        line = CTLineCreateWithAttributedString(
+                CFAttributedStringCreate(None, b"hello world".decode('latin1'), None))
+        self.assertIsInstance(line, CTLineRef)
+
+        run = CTLineGetGlyphRuns(line)[0]
+        self.assertIsInstance(run, CTRunRef)
+
+        r = CTRunGetAdvances(run, CFRange(1, 3), None)
+        self.assertIsInstance(r, (list, tuple))
+        self.assertEquals(len(r), 3)
+        for i in range(3):
+            self.assertIsInstance(r[i], CGSize)
+
+
+        try:
+            CTRunGetAdvancesPtr
+        except NameError:
+            pass
+        else:
+            self.fail("CTRunGetAdvancesPtr is defined")
 
 
 if __name__ == "__main__":
